@@ -28,7 +28,7 @@ pub fn zest_dec(
         text_out.push(hashed_out);
 
         //Compute partial digest
-        result_dgst ^= zest4096(hashed_out) + ctr_dgst;
+        result_dgst ^= zest4096(zest4096(hashed_out + ctr_dgst) ^ ctr_dgst);
         ctr_dgst.increment_block();
     }
     //Check if there *is* a encoded digest attached to the recieved data
