@@ -19,7 +19,7 @@ pub fn zest_digest(
     let mut result_block = init_result.unwrap_or_else(ZestBlock::new);
     let mut counter_block = init_ctr.unwrap_or_else(ZestBlock::new);
     for block in padded {
-        result_block ^= zest4096(block) + counter_block;
+        result_block ^= zest4096(zest4096(block + counter_block) ^ counter_block);
         counter_block.increment_block();
     }
     result_block
