@@ -28,7 +28,7 @@ pub fn zest_enc(
         cipher_text.push(cipher_block);
 
         //Compute partial digest
-        result_dgst ^= zest4096(text_block) + ctr_dgst;
+        result_dgst ^= zest4096(zest4096(text_block + ctr_dgst) ^ ctr_dgst);
         ctr_dgst.increment_block();
     }
     //Add the computed digest to the block stream
