@@ -42,6 +42,10 @@ impl ZestRand {
         self.hash_output = zest4096(self.seed).data_u8();
         self.byte_offset = byte_offset & 0x1FF;
     }
+    //Request current seed and offset in the CSPRNG
+    pub fn getseed(&self) -> (ZestBlock, usize) {
+        (self.seed, self.byte_offset)
+    }
     // Counts to the next block, (lower index ptr = higher place value)
     // and sets the hash output to None
     #[inline(always)]
